==> chainwallet-1.0.2.tar.gz: lib/src/ecdsa/Seed.dart <==

import 'dart:typed_data';

import 'package:chainwallet/src/utils/Util.dart';
import 'package:chainwallet/src/utils/B58IdentiferCodecs.dart';
import 'IkeyPair.dart';
import 'K256KeyPair.dart';

class Seed {

//  public static byte[] VER_K256 = new byte[]{(byte) B58IdentiferCodecs.VER_FAMILY_SEED};
//  public static byte[] VER_ED25519 = new byte[]{(byte) 0x1, (byte) 0xe1, (byte) 0x4b};
//  public static byte[] VER_SM = new byte[]{(byte)0x02,(byte)0xe2,(byte)0x4c};


  Uint8List seedBytes;
  Uint8List version =    Uint8List.fromList([B58IdentiferCodecs.VER_FAMILY_SEED]);


  //Constructor
  Seed(Uint8List seedBytes,{Uint8List version}){

      if(version != null){
        this.version = version;
      }
      this.seedBytes = seedBytes;
  }


  static Seed fromBase58(String b58) {

      Uint8List vK256  = Uint8List.fromList([B58IdentiferCodecs.VER_FAMILY_SEED]);
      List<Uint8List> versions = new List<Uint8List>();
      versions.add(vK256);

      var decoded = B58IdentiferCodecs.decodeMulti(b58, 16, versions);

      if(decoded != null && decoded.containsKey('payload')){
        return new Seed(decoded['payload']);
      }
      else{

        throw 'Bro, version is wrong yo';
      }
  }


  Uint8List bytes() {
    return seedBytes;
  }


   static Seed randomSeed(){
      Uint8List seedBytes = Util.getRandomBytes(16);
      return new Seed(seedBytes);
  }


  IKeyPair keyPair([int account = 0]) {


    return createKeyPair(seedBytes, account);


//    if (Arrays.equals(version, VER_ED25519)) {
//      if (account != 0) throw new AssertionError();
//      return EDKeyPair.from128Seed(seedBytes);
//    }  else if(Arrays.equals(version, VER_SM)){
//      try {
//        //return new SMKeyPair();
//        return null;
//      } catch (Exception e) {
//    e.printStackTrace();
//    return null;
//    }
//    }else {
//    return createKeyPair(seedBytes, account);
//    }

  }


  static IKeyPair createKeyPair(Uint8List seedBytes, int accountNumber) {

      BigInt secret, pub, privateGen;
      // The private generator (aka root private key, master private key)
      privateGen = K256KeyPair.computePrivateGen(seedBytes);

      Uint8List publicGenBytes = K256KeyPair.computePublicGenerator(privateGen);
      if(accountNumber == -1) {
        return new K256KeyPair(privateGen,Util.createBigIntFromUint8List(publicGenBytes));
      }else {

        secret = K256KeyPair.computeSecretKey(privateGen, publicGenBytes, accountNumber);
        pub = K256KeyPair.computePublicKey(secret);

        return new K256KeyPair(secret, pub);

      }


//  BigInteger secret, pub, privateGen;
//  // The private generator (aka root private key, master private key)
//  privateGen = K256KeyPair.computePrivateGen(seedBytes);
//
//  System.out.println("privateGen :" +  Utils.bigHex(privateGen));
//
//  byte[] publicGenBytes = K256KeyPair.computePublicGenerator(privateGen);
//
//
//  System.out.println("公钥1 :" +  Util.bytesToHex(publicGenBytes));
//
//  ;
//  if (accountNumber == -1) {
//  // The root keyPair
//  return new K256KeyPair(privateGen, Utils.uBigInt(publicGenBytes));
//  } else {
//  secret = K256KeyPair.computeSecretKey(privateGen, publicGenBytes, accountNumber);
//  pub = K256KeyPair.computePublicKey(secret);
//
//  System.out.println("secret :" +  secret + "  pub : " + pub);
//
//  //    System.out.println("secret :" +  Utils.bigHex(secret) + "  pub : " + Utils.bigHex(pub));
//
//
//
//
//  return new K256KeyPair(secret, pub);
 // }

  }


}

==> chainwallet-1.0.4.tar.gz: lib/src/ecdsa/Seed.dart <==
import 'dart:typed_data';

import 'package:chainwallet/src/utils/Util.dart';
import 'package:chainwallet/src/utils/B58IdentiferCodecs.dart';
import 'IkeyPair.dart';
import 'K256KeyPair.dart';

class Seed {
//  public static byte[] VER_K256 = new byte[]{(byte) B58IdentiferCodecs.VER_FAMILY_SEED};
//  public static byte[] VER_ED25519 = new byte[]{(byte) 0x1, (byte) 0xe1, (byte) 0x4b};
//  public static byte[] VER_SM = new byte[]{(byte)0x02,(byte)0xe2,(byte)0x4c};

  Uint8List seedBytes;
  Uint8List version = Uint8List.fromList([B58IdentiferCodecs.VER_FAMILY_SEED]);

  //Constructor
  Seed(Uint8List seedBytes, {Uint8List version}) {
    if (version != null) {
      this.version = version;
    }
    this.seedBytes = seedBytes;
  }

  static Seed fromBase58(String b58) {
    Uint8List vK256 = Uint8List.fromList([B58IdentiferCodecs.VER_FAMILY_SEED]);
    List<Uint8List> versions = new List<Uint8List>();
    versions.add(vK256);

    var decoded = B58IdentiferCodecs.decodeMulti(b58, 16, versions);

    if (decoded != null && decoded.containsKey('payload')) {
      return new Seed(decoded['payload']);
    } else {
      throw 'Bro, version is wrong yo';
    }
  }

  Uint8List bytes() {
    return seedBytes;
  }

  static Seed randomSeed() {
    Uint8List seedBytes = Util.getRandomBytes(16);
    return new Seed(seedBytes);
  }

  IKeyPair keyPair([int account = 0]) {
    return createKeyPair(seedBytes, account);

//    if (Arrays.equals(version, VER_ED25519)) {
//      if (account != 0) throw new AssertionError();
//      return EDKeyPair.from128Seed(seedBytes);
//    }  else if(Arrays.equals(version, VER_SM)){
//      try {
//        //return new SMKeyPair();
//        return null;
//      } catch (Exception e) {
//    e.printStackTrace();
//    return null;
//    }
//    }else {
//    return createKeyPair(seedBytes, account);
//    }
  }

  static IKeyPair createKeyPair(Uint8List seedBytes, int accountNumber) {
    BigInt secret, pub, privateGen;
    // The private generator (aka root private key, master private key)
    privateGen = K256KeyPair.computePrivateGen(seedBytes);

    Uint8List publicGenBytes = K256KeyPair.computePublicGenerator(privateGen);
    if (accountNumber == -1) {
      return new K256KeyPair(
          privateGen, Util.createBigIntFromUint8List(publicGenBytes));
    } else {
      secret = K256KeyPair.computeSecretKey(
          privateGen, publicGenBytes, accountNumber);
      pub = K256KeyPair.computePublicKey(secret);

      return new K256KeyPair(secret, pub);
    }

//  BigInteger secret, pub, privateGen;
//  // The private generator (aka root private key, master private key)
//  privateGen = K256KeyPair.computePrivateGen(seedBytes);
//
//  System.out.println("privateGen :" +  Utils.bigHex(privateGen));
//
//  byte[] publicGenBytes = K256KeyPair.computePublicGenerator(privateGen);
//
//
//  System.out.println("公钥1 :" +  Util.bytesToHex(publicGenBytes));
//
//  ;
//  if (accountNumber == -1) {
//  // The root keyPair
//  return new K256KeyPair(privateGen, Utils.uBigInt(publicGenBytes));
//  } else {
//  secret = K256KeyPair.computeSecretKey(privateGen, publicGenBytes, accountNumber);
//  pub = K256KeyPair.computePublicKey(secret);
//
//  System.out.println("secret :" +  secret + "  pub : " + pub);
//
//  //    System.out.println("secret :" +  Utils.bigHex(secret) + "  pub : " + Utils.bigHex(pub));
//
//
//
//
//  return new K256KeyPair(secret, pub);
    // }
  }
}
